# Web API 函数调用接口说明

## 1. BindDeviceToUser - 绑定设备到用户

绑定用户标识到设备上，方便之后按照用户标识来管控设备。

### 请求方法
POST

### URL
`https://one.baibaomen.com/api/services/app/Devices/BindDeviceToUser`

### 参数
- `deviceUser` - 设备用户的可读标识（例如用户的账号、邮箱、手机号）。
- `deviceCode` - 设备SN码。
- `secretKey` - 调用方的授权密钥。

### 异常
- `UnauthorizedAccessException`
- `InvalidDataException`

### CURL 调用示例
```bash
curl -X POST "https://one.baibaomen.com/api/services/app/Devices/BindDeviceToUser" \
     -d "deviceUser=[用户标识]&deviceCode=[设备SN码]&secretKey=[授权密钥]"
```

## 2. SetUserPolicy - 设置用户设备的管控措施

设置用户设备的管控措施。

### 请求方法
POST

### URL
`https://one.baibaomen.com/api/services/app/Devices/SetUserPolicy`

### 参数
- `deviceUser` - 设备绑定用户的标识。
- `policy` - 管控措施。
- `secretKey` - 调用方的授权密钥。

### 异常
- `UnauthorizedAccessException`
- `InvalidDataException`

### CURL 调用示例
```bash
curl -X POST "https://one.baibaomen.com/api/services/app/Devices/SetUserPolicy" \
     -F "deviceUser=[用户标识]" \
     -F "policy=[管控措施]" \
     -F "secretKey=[授权密钥]"
```

## 3. GetUserPolicy - 获取用户的管控措施

获取用户绑定设备的管控措施。

### 请求方法
GET

### URL
`https://one.baibaomen.com/api/services/app/Devices/GetUserPolicy`

### 参数
- `deviceUser` - 设备绑定的用户标识。
- `secretKey` - 调用方的授权密钥。

### 异常
- `UnauthorizedAccessException`
- `InvalidDataException`

### CURL 调用示例
```bash
curl "https://one.baibaomen.com/api/services/app/Devices/GetUserPolicy?deviceUser=[用户标识]&secretKey=[授权密钥]"
```

## 4. SetDevicePolicy - 设置设备的管控措施

设置设备的管控措施。

### 请求方法
POST

### URL
`https://one.baibaomen.com/api/services/app/Devices/SetDevicePolicy`

### 参数
- `deviceCode` - 设备码。
- `policy` - 管控措施。
- `secretKey` - 调用方的授权密钥。

### 异常
- `UnauthorizedAccessException`
- `InvalidDataException`

### CURL 调用示例
```bash
curl -X POST "https://one.baibaomen.com/api/services/app/Devices/SetDevicePolicy" \
     -F "deviceCode=[设备码]" \
     -F "policy=[管控措施]" \
     -F "secretKey=[授权密钥]"
```

## 5. GetDevicePolicy - 获取设备管控措施

获取设备的管控措施。

### 请求方法
GET

### URL
`https://one.baibaomen.com/api/services/app/Devices/GetDevicePolicy`

### 参数
- `deviceCode` - 设备码。
- `secretKey` - 调用方的授权密钥。

### 异常
- `UnauthorizedAccessException`
- `InvalidDataException`

### CURL 调用示例
```bash
curl "https://one.baibaomen.com/api/services/app/Devices/GetDevicePolicy?deviceCode=[设备码]&secretKey=[授权密钥]"
```

## 6. SetOrgPolicy - 设置组织结构节点的管控措施

设置组织结构节点的管控措施。

### 请求方法
POST

### URL
`https://one.baibaomen.com/api/services/app/Devices/SetOrgPolicy`

### 参数
- `orgUnitCode` - 组织结构节点代码，例如“1.2.18”。
- `policy` - 要设置的管控措施，json格式。
- `secretKey` - 调用方的授权密钥。

### 异常
- `UnauthorizedAccessException`
- `InvalidDataException`

### CURL 调用示例
```bash
curl -X POST "https://one.baibaomen.com/api/services/app/Devices/SetOrgPolicy" \
     -F "orgUnitCode=[组织结构节点代码]" \
     -F "policy=[管控措施]" \
     -F "secretKey=[授权密钥]"
```

## 7. GetOrgPolicy - 获取组织机构节点的管控措施

获取组织机构节点的管控措施。

### 请求方法
GET

### URL
`https://one.baibaomen.com/api/services/app/Devices/GetOrgPolicy`

### 参数
- `orgUnitCode` - 组织结构节点代码，例如“1.2.18”。
- `secretKey` - 调用方的授权密钥。

### 异常
- `UnauthorizedAccessException`
- `InvalidDataException`

### CURL 调用示例
```bash
curl "https://one.baibaomen.com/api/services/app/Devices/GetOrgPolicy?orgUnitCode=[组织结构节点代码]&secretKey=[授权密钥]"
```
